@@ -17,6 +17,8 @@ from django_jinja.management.commands.makemessages import (
 LOOKUP_FLAGS = re.MULTILINE | re.IGNORECASE
 TAG_REGEX_LOOKUPER = re.compile(r'\/[a-z0-9_-]+\>', LOOKUP_FLAGS)
 ES6_STRING_TEMPLATES = re.compile(r'\`(([^\`\\]|(\\(.|\n)))*?)\`', LOOKUP_FLAGS)
+PUG_INCLUDES = re.compile(r'^\s*include\s+.+$', re.MULTILINE)
+PUG_EXTENDS = re.compile(r'^\s*extends\s+.+$', re.MULTILINE)
 
 
 def clear_regex_tags(content: str) -> str:
@@ -31,10 +33,17 @@ def clear_es6(content: str) -> str:
     return content
 
 
+def clear_pug(content: str) -> str:
+    content = PUG_INCLUDES.sub('', content)
+    content = PUG_EXTENDS.sub('', content)
+    return content
+
+
 def clear_all(content: str) -> str:
     return reduce(lambda acc, x: x(acc), (
         clear_regex_tags,
         clear_es6,
+        clear_pug,
     ), content)
 
 
